/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __AIR_HOME_DATAMGR_H__
#define __AIR_HOME_DATAMGR_H__

#include <Eina.h>
#include <stdbool.h>

enum datamgr_item_select_action {
	ITEM_SELECT_ACTION_LAUNCH,
	ITEM_SELECT_ACTION_PUSH,
	ITEM_SELECT_ACTION_POP,
	ITEM_SELECT_ACTION_SWITCH,
	ITEM_SELECT_ACTION_UPDATE,
	ITEM_SELECT_ACTION_DELETE,
	ITEM_SELECT_ACTION_MAX
};

struct datamgr {
	Eina_List *list;
	const char *view_id;
	struct data_class *dclass;
};

struct datamgr_item {
	char *title;
	char *subtitle;
	char *icon;
	char *focus_icon;
	char *thumbnail;
	char *parameter;
	char *key;
	char *value;
	bool noti;
	enum datamgr_item_select_action action;
	int type;
	time_t time;
};

struct data_class {
	bool (*init)(struct datamgr *dm);
	void (*fini)(struct datamgr *dm);
	void (*select)(struct datamgr_item *di);
	Eina_List *(*get_items)(struct datamgr *dm);
	void (*clear)(struct datamgr *dm);
	void (*add)(struct datamgr *dm, const char *title, const char *icon,
			const char *parameter);
	/* It should be added later */
};

struct datamgr *datamgr_init(struct data_class *dclass, const char *view_id);
void datamgr_fini(struct datamgr *dm);
Eina_List *datamgr_get_items(struct datamgr *dm);
void datamgr_select_item(struct datamgr *dm, struct datamgr_item *di);
void datamgr_clear_item(struct datamgr *dm);
void datamgr_add_item(struct datamgr *dm, const char *title, const char *icon,
		const char *parameter);

#endif /* __AIR_HOME_DATAMGR_H__ */
